@@ -33,6 +33,7 @@ $fields_site_edit = array(
 	'spacer0' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('Site Information'),
+		'collapsible' => 'true'
 	),
 	'name' => array(
 		'method' => 'textbox',
@@ -98,12 +99,14 @@ $fields_site_edit = array(
 		'max_length' => '30'
 	),
 	'timezone' => array(
-		'method' => 'drop_sql',
+		'method' => 'drop_callback',
 		'friendly_name' => __('TimeZone'),
 		'description' => __('The TimeZone for the Site.'),
-		'value' => '|arg1:timezone|',
-		'sql' => 'SELECT Name AS id, Name AS name FROM mysql.time_zone_name ORDER BY name'
-	),
+		'sql' => 'SELECT Name AS id, Name AS name FROM mysql.time_zone_name ORDER BY name',
+		'action' => 'ajax_tz',
+		'id' => '|arg1:timezone|',
+		'value' => '|arg1:timezone|'
+		),
 	'latitude' => array(
 		'method' => 'textbox',
 		'friendly_name' => __('Latitude'),
@@ -163,6 +166,15 @@ switch (get_request_var('action')) {
 	case 'actions':
 		form_actions();
 
+		break;
+	case 'ajax_tz':
+		print json_encode(db_fetch_assoc_prepared('SELECT Name AS label, Name AS `value` 
+			FROM mysql.time_zone_name 
+			WHERE Name LIKE ?
+			ORDER BY Name
+			LIMIT 10',
+			array('%' . get_nfilter_request_var('term') . '%')));
+
 		break;
 	case 'edit':
 		top_header();
@@ -209,7 +221,7 @@ function form_save() {
 
 			if ($site_id) {
 				raise_message(1);
-			}else{
+			} else {
 				raise_message(2);
 			}
 		}
@@ -248,7 +260,7 @@ function form_actions() {
 	$site_list = ''; $i = 0;
 
 	/* loop through each of the graphs selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -278,7 +290,7 @@ function form_actions() {
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Delete Site', 'Delete Sites', sizeof($site_array)) . "'>";
 		}
-	}else{
+	} else {
 		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Site.') . "</span></td></tr>\n";
 		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 	}
@@ -313,13 +325,13 @@ function site_edit() {
 	if (!isempty_request_var('id')) {
 		$site = db_fetch_row_prepared('SELECT * FROM sites WHERE id = ?', array(get_request_var('id')));
 		$header_label = __('Site [edit: %s]', htmlspecialchars($site['name']));
-	}else{
+	} else {
 		$header_label = __('Site [new]');
 	}
 
 	form_start('sites.php', 'site');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	draw_edit_form(
 		array(
@@ -328,7 +340,7 @@ function site_edit() {
 		)
 	);
 
-	html_end_box();
+	html_end_box(true, true);
 
 	form_save_button('sites.php', 'return');
 }
@@ -370,7 +382,7 @@ function sites() {
 
 	if (get_request_var('rows') == '-1') {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -416,7 +428,7 @@ function sites() {
 			<script type='text/javascript'>
 
 			function applyFilter() {
-				strURL = 'sites.php?filter='+$('#filter').val()+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
+				strURL = 'sites.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
 				loadPageNoHeader(strURL);
 			}
 
@@ -450,7 +462,7 @@ function sites() {
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%')";
-	}else{
+	} else {
 		$sql_where = '';
 	}
 
@@ -499,7 +511,7 @@ function sites() {
 			form_checkbox_cell($site['name'], $site['id']);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Sites Found') . "</em></td></tr>\n";
 	}
 
